all.Valms<-function(){
     cat("\n")
     note_for_Valss_input()
     cat("\n")
     note_for_close_window()
     ValMSpar<-data.frame(subject=c(1,2),age=c(0),INDI=c(0),CBZ=c(0),ka=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     ValMSpar<-edit(ValMSpar)
##     ValMSpar<-ymscheck(ValMSpar)
     Val.ms(length(ValMSpar$subject),ValMSpar$c,ValMSpar$tau,ValMSpar$ts,ValMSpar$D,ValMSpar$age,ValMSpar$CBZ,ValMSpar$INDI,ValMSpar$ka)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Valss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Valcpr(ValMSpar$ka,ValMSpar$D,ValMSpar$tau,ValMSpar$ts)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-Valcpr(ValMSpar$ka,ValMSpar$D,ValMSpar$tau,ValMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n") 
     cal.again()
}